==> hoteldruid-mod-sv_3.0.3-1.tar.gz: sv/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica il documento":  			$messaggio = "&Auml;ndra dokument"; break;
case "Salva le modifiche":  			$messaggio = "Spara f&ouml;r&auml;ndringar"; break;
case "Visualizza il documento":  		$messaggio = "Se dokument"; break;
case "Documento salvato":  			$messaggio = "Dokumentet sparat"; break;
case "Variabili":  				$messaggio = "Variabler"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "Formato del documento":  			$messaggio = "Dokumentformat"; break;
case "EMAIL":  					$messaggio = "E-POST"; break;
case "Oggetto":  				$messaggio = "&Auml;mne"; break;
case "Formato del documento cambiato":  	$messaggio = "Dokumentformat &auml;ndrat"; break;
case "Oggetto cambiato":  			$messaggio = "&Auml;mne &auml;ndrat"; break;
case "Allegato":  				$messaggio = "Bilaga"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Mandare una copia bcc":  			$messaggio = "S&auml;nd en hemlig kopia"; break;
case "al mittente":  				$messaggio = "till avs&auml;ndaren"; break;
case "all'indirizzo":  				$messaggio = "till adressen"; break;
case "Allegato salvato":  			$messaggio = "Bilaga sparad"; break;
case "Allegato eliminato":  			$messaggio = "Bilaga borttagen"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Hemliga kopior &auml;ndrade"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED DELEN SOM SKA UPPREPAS F&Ouml;R VARJE BOKNING"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSG&Auml;STER"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSKOSTNADER"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Spara dokument med progressiva nummer i mappen"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumenten kommer inte sparas"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumenten kommer sparas i mappen"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "ERS&Auml;TT MED DEL SOM SKA UPPREPAS F&Ouml;R VARJE ARRAY-V&Auml;RDE"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "al":  					$messaggio = "to"; break;
case "e":  					$messaggio = "and"; break;
case "Modifica Documento":  			$messaggio = "Modify Document"; break;
case "documento":  				$messaggio = "document"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "ripetizione prenotazioni":  		$messaggio = "reservations repetition"; break;
case "ripetizione ospiti":  			$messaggio = "guests repetition"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "valore":  				$messaggio = "value"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
case "Password":  				$messaggio = "Password"; break;
case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "se la variabile":  			$messaggio = "if the variable"; break;
case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
case "come date":  				$messaggio = "as dates"; break;
case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
case "Tutti i clienti":  			$messaggio = "All the clients"; break;
case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
case "ripetizione documenti salvati":  		$messaggio = "saved documents repetition"; break;
case "formato dell'utente":  			$messaggio = "format from user"; break;
case "Formato dei soldi":  			$messaggio = "Money format"; break;
case "Formato delle date":  			$messaggio = "Dates format"; break;
case "Formati predefiniti del documento cambiati":	$messaggio = "Default formats for the document changed"; break;
case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "existing documents will never be overwritten, each time the API is called a new document will be saved"; break;
case "Tutti i pagamenti nella cassa":  		$messaggio = "All payments in cashbox"; break;
case "nome_cassa":  				$messaggio = "cashbox_name"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.8-1.tar.gz: sv/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica il documento":  			$messaggio = "&Auml;ndra dokument"; break;
case "Salva le modifiche":  			$messaggio = "Spara f&ouml;r&auml;ndringar"; break;
case "Visualizza il documento":  		$messaggio = "Se dokument"; break;
case "Documento salvato":  			$messaggio = "Dokumentet sparat"; break;
case "Variabili":  				$messaggio = "Variabler"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "Cambia":  				$messaggio = "&Auml;ndra"; break;
case "Formato del documento":  			$messaggio = "Dokumentformat"; break;
case "EMAIL":  					$messaggio = "E-POST"; break;
case "Oggetto":  				$messaggio = "&Auml;mne"; break;
case "Formato del documento cambiato":  	$messaggio = "Dokumentformat &auml;ndrat"; break;
case "Oggetto cambiato":  			$messaggio = "&Auml;mne &auml;ndrat"; break;
case "Allegato":  				$messaggio = "Bilaga"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Mandare una copia bcc":  			$messaggio = "S&auml;nd en hemlig kopia"; break;
case "al mittente":  				$messaggio = "till avs&auml;ndaren"; break;
case "all'indirizzo":  				$messaggio = "till adressen"; break;
case "Allegato salvato":  			$messaggio = "Bilaga sparad"; break;
case "Allegato eliminato":  			$messaggio = "Bilaga borttagen"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Hemliga kopior &auml;ndrade"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED DELEN SOM SKA UPPREPAS F&Ouml;R VARJE BOKNING"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSG&Auml;STER"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "ERS&Auml;TT MED EN LISTA &Ouml;VER BOKNINGSKOSTNADER"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Spara dokument med progressiva nummer i mappen"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumenten kommer inte sparas"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumenten kommer sparas i mappen"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "ERS&Auml;TT MED DEL SOM SKA UPPREPAS F&Ouml;R VARJE ARRAY-V&Auml;RDE"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "al":  					$messaggio = "to"; break;
case "e":  					$messaggio = "and"; break;
case "o":  					$messaggio = "or"; break;
case "Modifica Documento":  			$messaggio = "Modify Document"; break;
case "documento":  				$messaggio = "document"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "ripetizione prenotazioni":  		$messaggio = "reservations repetition"; break;
case "ripetizione ospiti":  			$messaggio = "guests repetition"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "valore":  				$messaggio = "value"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "Nome con cui vedere e scaricare il documento":	$messaggio = "Name for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
case "Password":  				$messaggio = "Password"; break;
case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "se la variabile":  			$messaggio = "if the variable"; break;
case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
case "come date":  				$messaggio = "as dates"; break;
case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
case "Tutti i clienti":  			$messaggio = "All the clients"; break;
case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
case "ripetizione documenti salvati":  		$messaggio = "saved documents repetition"; break;
case "formato dell'utente":  			$messaggio = "format from user"; break;
case "Formato dei soldi":  			$messaggio = "Money format"; break;
case "Formato delle date":  			$messaggio = "Dates format"; break;
case "Formati predefiniti del documento cambiati":	$messaggio = "Default formats for the document changed"; break;
case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "existing documents will never be overwritten, each time the API is called a new document will be saved"; break;
case "Tutti i pagamenti nella cassa":  		$messaggio = "All payments in cashbox"; break;
case "nome_cassa":  				$messaggio = "cashbox_name"; break;
case "nome del documento o del file salvato":  	$messaggio = "document name or saved file name"; break;
case "variabile":  				$messaggio = "variable"; break;
case "Verrà usato il nome del documento (o il nome del file salvato) come nome per il file scaricato":	$messaggio = "The name of the document (or the name of the saved file) will be used as the name for the downloaded file"; break;
case "Verrà usato il valore della variabile":  	$messaggio = "The value of the variable"; break;
case "come nome del file scaricato":  		$messaggio = "will be used as the name for the downloaded file"; break;
case "escludendo l'estensione":  		$messaggio = "excluding extension"; break;
case "Se la variabile non è definita verrà usato il nome del documento":	$messaggio = "If the variable is not defined then the document name will be used"; break;
case "È comunque possibile mostrare <em>una sola ripetizione per ogni cliente</em> usando le variabili":	$messaggio = "However, it is possible to show <em>only one repetition per client</em> using variables"; break;
case "in una condizione come questa":  		$messaggio = "in a condition like this one"; break;
case "aggiungi ora questa condizione al documento":	$messaggio = "add now this condition to the document"; break;
case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "This way data from previous repetitions can be stored in one or more arrays of variable"; break;
case "È stato trovato un allegato uguale":  	$messaggio = "An identical attachment was found"; break;
case "Unisci più condizioni con":  		$messaggio = "Merge multiple conditions with"; break;
case "Indirizzi IP":  				$messaggio = "IP addresses"; break;
case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "comma separated list, any IP if empty"; break;
case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "The IP addresses allowed to access the document API have been changed"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "alla URL verranno cercate solo (o anche) le prenotazioni cancellate, anche nelle URL successive":	$messaggio = "to the URL will search only (or also) deleted reservations, also in subsequent URLs"; break;
case "numero del":  				$messaggio = "number from"; break;
case "prima di essere importata nel":  		$messaggio = "before being imported into"; break;
case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombrare il database":	$messaggio = "reuse the existing attachment or make it the default to avoid cluttering the database"; break;
case "considerate sempre come raggruppate a destra":	$messaggio = "always considered as grouped on the right"; break;
case "Il valore può essere un testo tra virgolette \" o un'altra variabile":	$messaggio = "The value can be a text in quotes \" or another variable"; break;
case "condizione":  				$messaggio = "condition"; break;
case "Invia anche la versione alternativa in testo semplice":	$messaggio = "Also send the alternative version in plain text"; break;
case "etichette html rimosse":  		$messaggio = "html tags removed"; break;
case "Immagine inline":  			$messaggio = "Inline image"; break;
case "Immagine salvata":  			$messaggio = "Image saved"; break;
case "incorporata":  				$messaggio = "embedded"; break;
case "Immagine eliminata":  			$messaggio = "Image deleted"; break;
case "È stata trovata una immagine uguale":  	$messaggio = "An identical image was found"; break;
case "riutilizzare l'immagine esistente per evitare di ingombrare il database":	$messaggio = "reuse the existing image to avoid cluttering the database"; break;
case "Pagine dove non mostrare questo documento":	$messaggio = "Pages where this document should not be displayed"; break;
case "tabella del mese":  			$messaggio = "month table"; break;
case "tabella delle prenotazioni":  		$messaggio = "reservations table"; break;
case "tabella dei clienti":  			$messaggio = "clients table"; break;
case "tabella dei messaggi":  			$messaggio = "messages table"; break;
case "controllo disponibilità":  		$messaggio = "availability check"; break;
case "modifica della prenotazione":  		$messaggio = "reservation modification"; break;
case "modifica del cliente":  			$messaggio = "client modification"; break;
case "punto vendita":  				$messaggio = "point of sale"; break;
case "casse":  					$messaggio = "cashboxes"; break;
case "È stata aggiunta la pagina dove non mostrare il documento":	$messaggio = "The page where the document should not be displayed has been added"; break;
case "È stata eliminata la pagina dove non mostrare il documento":	$messaggio = "The page where the document should not be displayed has been removed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
